<?php
/**
 * @file
 * Inc file defines utility functions to be used accross markdown exporter module
 *
 */

/**
 * Creating content files in MD format
 *
 * Converts the content of the specified types to markdown, and creates a zip containing them.
 */
function content_export_in_markdown($types, $mode = '') {
  
  // to include Markdownify classes
  include_once('Markdownify/src/Parser.php');
  include_once('Markdownify/src/Converter.php');
  //include_once('Markdownify/src/ConverterExtra.php');

  // Creating directory to store MD files
  $md_dir = 'public://' . variable_get('markdown_exporter_dir', 'markdown_export');
  $success = file_prepare_directory($md_dir, FILE_CREATE_DIRECTORY | FILE_MODIFY_PERMISSIONS);
 
  $mdObj = new Markdownify\Converter(0, MDFY_BODYWIDTH, MDFY_KEEPHTML);
 
  $query = new EntityFieldQuery();
  $query->entityCondition('entity_type', 'node')
                          ->entityCondition('bundle', $types)
                          ->propertyCondition('status', 1);
                          
  
  $query->propertyOrderBy('created', 'ASC');

  $node_info = $query->execute();

  if (count($node_info)) {    
    $nids = array_keys($node_info['node']);    
    $node_details = node_load_multiple($nids);    
  } 
 
  // Pull the list of fields(per content type) to be exported
	$entity_field_json = variable_get('markdown_exporter_fields', '{"page":{"formatter":["type", "title","created"],"content":["body"]}}');
  $entity_fields = json_decode($entity_field_json);

  $files = array();
  if(!empty($node_details)) {
    foreach ($node_details as $node) {
      		
      // Get the path alias
      $url_alias = drupal_get_path_alias('node/'.$node->nid);
      
      // formatting the alias
      $url_alias_formatted = strpos($url_alias, '/') ? str_replace('/', "-", $url_alias) : $url_alias;
       
      // Content file in .md format
      $file_name = date('Y-m-d', $node->created) . '-' . $url_alias_formatted . '.md';
      
      // to pick up formatter & body fields as per configuration
      if (property_exists($entity_fields, $node->type) && !empty($entity_fields->{$node->type})) {
        $formatter_fields = $entity_fields->{$node->type}->formatter;
        $content_fields = $entity_fields->{$node->type}->content;
      } else {
        $formatter_fields = array('type', 'title', 'created');
        $content_fields = array('body');
      }  
      
      // Preparing MD formatter
      $formatter =  "---\n";
      $formatter .=  "uri:" . $url_alias . "\n";
      
      foreach($formatter_fields as $fld1) {
        $field_value = '';
        $formatter_field_data = '';
        if(isset($node->{$fld1})) {
          $formatter_field_data = $node->{$fld1};
          if(!is_array($formatter_field_data)) {  
            $field_value = $formatter_field_data;
          } else {
            if(isset($formatter_field_data[$node->language][0]['value'])) { 
              $field_value = $formatter_field_data[$node->language][0]['value'];
            } else {
              if(isset($formatter_field_data[$node->language][0]['uri']) && !empty($formatter_field_data[$node->language][0]['uri'])){ // for image field
                $field_value = file_create_url($formatter_field_data[$node->language][0]['uri']);
              }

            }
          }	
        }
        
        $field_value = !empty($field_value)?$field_value:'NULL';
        $formatter .=  $fld1 . ":" . $field_value . "\n" ;
      }
      $formatter .=  "---\n\n";

      // Preparing MD content
      $mdcontent = '';
      foreach($content_fields as $fld2) {
        if(isset($node->{$fld2})) {
          $content_field_data = $node->{$fld2};
          if(!is_array($content_field_data)) {  
            $field_value = $content_field_data;
          } else {
            $field_value = $content_field_data[$node->language][0]['value'];
          } 
          $mdcontent .= $mdObj->parseString($field_value);
        }  
      }

      // Markdown file content
      $contents = $formatter . $mdcontent;
      
      // and create the file
      $replace = (variable_get('markdown_file_overwrite') == TRUE) ? FILE_EXISTS_REPLACE : FILE_EXISTS_RENAME ;
      file_unmanaged_save_data($contents, $md_dir . '/' . $file_name, $replace);
    }
  }
  if ($mode == 'cli') {
    $msg = t('MarkDown files are generated & saved in') . ' files/'. variable_get('markdown_exporter_dir', 'markdown_export');
  } else {
    $msg = t('MarkDown files are generated!') . ' ' . l('Click to download the files in ziped format', 'markdown-file-download');
  } 
  drupal_set_message($msg);
}

function markdown_export_download(){
  $md_dir = 'public://' . variable_get('markdown_exporter_dir', 'markdown_export');
  $zip_file = variable_get('markdown_exporter_dir', 'markdown_export') . '_' . REQUEST_TIME . '.zip';
  $zip_uri = 'temporary://' . $zip_file;

  if ($handle = opendir($md_dir)) {
    $zip = new ZipArchive();
   // echo drupal_realpath($zip_uri);exit;
    if ($zip->open(drupal_realpath($zip_uri), ZipArchive::CREATE) !== TRUE) {
        exit("cannot open <$zip_file>\n");
    }

    while (false !== ($file_name = readdir($handle))) {
      if ($file_name != '.' && $file_name != '..') {
        $zip->addFile(drupal_realpath($md_dir).'/'.$file_name, $file_name);
      }
    }
    closedir($handle);
    $zip->close();
    
    header("Cache-Control: public");
    header("Content-Type: application/zip");
    header("Cache-Control: no-store, no-cache, must-revalidate");
    header("Cache-Control: post-check=0, pre-check=0");
    header("Content-Disposition: attachment; filename=\"$zip_file\";" );
    header("Content-Transfer-Encoding: binary");

    $fp = fopen(drupal_realpath($zip_uri), 'rb');
    fpassthru($fp);
    drupal_exit();
  }
}